=======

History

=======

0.1.0 (2023-09-03)

* First release on PyPI.

+++++++++++++++++++

0.1.4 (2023-09-04)

+++++++++++++++++++

0.1.5 (2023-09-04)

+++++++++++++++++++

0.1.6 (2023-09-29)

+++++++++++++++++++

0.1.7 (2023-09-29)

**Bugfixes**

- Error with MTS,LTS, MIS and LIS priority rules fixed.
- Bug related to incorrect choosing of activities under the condition of a priority rule tie, was fixed.

+++++++++++++++++++

0.1.8 (2023-10-03)

- Weak forbidden set function added
- Minimum forbidden set function added
- Simple monte carlo buffer analysis added
- Possibility to create a project from a .rcp file and from instances of the CV dataset

+++++++++++++++++++

0.1.9 (2023-10-03)

- Extra information added to the monte carlo buffer analysis methods
- Critical Path Method returns a dataframe with the basic outputs ES,EF,LS,LF,F

+++++++++++++++++++

0.1.10 (2023-10-03)

- Bug fix with the monte carlo buffer analysis methods

+++++++++++++++++++

0.1.11 (2023-10-03)

+++++++++++++++++++

0.1.12 (2023-10-08)

- Feasible subset function added
- Function that calculate naive bounds for each activity, based on a time horizon

+++++++++++++++++++

0.1.13 (2023-10-08)

- Bug fix with the outputs of forbidden sets and feasible set.

------------------


